import { jsx, Fragment } from "react/jsx-runtime";
import { c as z, o as objectType, s as stringType, d as ZodNumber } from "./index-loDVO1Vh.js";
import "@netlify/ui";
import { useState, useEffect, useCallback } from "react";
import "./components/Card/main.js";
import "./components/vendor/Card/Card.js";
import "./components/CodeBlock/highlight.js";
import { r as register_1 } from "./index-C9X9mBSm.js";
import { useNetlifyExtensionUIFetch } from "./use_netlify_extension_ui_fetch.js";
import { useNetlifySDK } from "./use_netlify_sdk.js";
import { CardLoader } from "./components/CardLoader.js";
import "./components/vendor/Checkbox.js";
import "./components/vendor/FormField.js";
import "./components/vendor/FormFieldSecret.js";
import "./components/vendor/Select/Select.js";
import { Form } from "./components/Form/Form.js";
import "./components/Link/Link.js";
import "./NetlifySDKProvider.js";
import "./index.esm-CHFNDxn-.js";
import "@netlify/sdk--ui-core";
import { Checkbox } from "./components/Form/Fields/Checkbox.js";
import { FormField } from "./components/Form/Fields/FormField.js";
import { FormFieldSecret } from "./components/Form/Fields/FormFieldSecret.js";
import "./components/SurfaceRouter/SurfaceRouterContext.js";
import { getZodField, getZodFieldTypeName } from "./components/SmartForm/zod-helpers.js";
register_1(z);
const createCommonDataSourceSchema = (configSchema) => objectType({
  name: stringType().trim().min(1),
  prefix: stringType().trim().min(1).regex(
    /^$|^[A-Z][A-Za-z0-9_]*$/,
    "Must start with an uppercase letter and only consist of alphanumeric characters and underscores"
  ),
  config: configSchema
});
const createCommonDataSourceFieldsMeta = (configFieldsMeta) => ({
  name: {
    label: "Data Source Name",
    name: "name"
  },
  prefix: {
    label: "Data Source Prefix",
    helpText: "The prefix to use for types synced from this data source. It must start with an uppercase letter and can only consist of alphanumeric characters and underscores. For example, Product becomes {Prefix}Product."
  },
  config: configFieldsMeta
});
var ConnectorFormType = /* @__PURE__ */ ((ConnectorFormType2) => {
  ConnectorFormType2["VISUAL_EDITOR"] = "CREATE";
  ConnectorFormType2["CONNECT"] = "CONNECT";
  return ConnectorFormType2;
})(ConnectorFormType || {});
const ConnectorForm = ({
  schema,
  formType,
  onSubmit: onSubmitProp,
  fieldsMeta
}) => {
  const mergedSchema = createCommonDataSourceSchema(
    schema
  );
  const mergedFieldsMeta = createCommonDataSourceFieldsMeta(fieldsMeta);
  console.log({ mergedFieldsMeta });
  const sdk = useNetlifySDK();
  const uiFetch = useNetlifyExtensionUIFetch();
  const [currentValues, setCurrentValues] = useState();
  const [isLoading, setIsLoading] = useState(true);
  let resourceIdParam = void 0;
  if (formType === "CONNECT") {
    resourceIdParam = `dataLayerId=${sdk.context.dataLayerId ?? ""}`;
  } else if (formType === "CREATE") {
    resourceIdParam = `siteId=${sdk.context.siteId ?? ""}&projectId=${sdk.context.projectId ?? ""}`;
  }
  const endpointURL = `/.netlify/functions/${formType.toLocaleLowerCase()}?${resourceIdParam ?? ""}&configurationId=${sdk.context.configurationId ?? ""}`;
  useEffect(() => {
    void uiFetch(endpointURL).then(async (res) => {
      const body = await res.json();
      setCurrentValues(body.data);
      setIsLoading(false);
    });
  });
  const onSubmit = useCallback(
    async (formValues) => {
      if (typeof onSubmitProp === "function") {
        await onSubmitProp(formValues);
      } else {
        await uiFetch(endpointURL, {
          method: "POST",
          body: JSON.stringify(formValues)
        });
        sdk.requestTermination();
      }
    },
    [onSubmitProp, uiFetch, sdk, endpointURL]
  );
  if (isLoading) {
    return /* @__PURE__ */ jsx(CardLoader, {});
  }
  return /* @__PURE__ */ jsx(
    SmartForm,
    {
      schema: mergedSchema,
      fieldsMeta: mergedFieldsMeta,
      defaultValues: currentValues,
      onSubmit
    }
  );
};
const SmartForm = ({
  defaultValues,
  onSubmit,
  schema,
  fieldsMeta
}) => {
  return /* @__PURE__ */ jsx(Form, { defaultValues, onSubmit, schema, children: Object.entries(schema.shape).map(
    ([key, value], idx) => {
      const zodField = getZodField(value);
      const fieldType = getZodFieldTypeName(zodField);
      if (fieldType === "ZodObject") {
        let nestedFieldsMeta = void 0;
        if (key in fieldsMeta) {
          nestedFieldsMeta = fieldsMeta[key];
        }
        return /* @__PURE__ */ jsx(
          ZodFormFields,
          {
            name: key,
            zodFieldValue: value,
            fieldsMeta: nestedFieldsMeta
          },
          `${idx.toString()}:${key}`
        );
      } else {
        const fieldMeta = fieldsMeta[key];
        return /* @__PURE__ */ jsx(
          ZodFormField,
          {
            name: key,
            zodFieldType: fieldType,
            fieldMeta
          },
          `${idx.toString()}:${key}`
        );
      }
    }
  ) });
};
const ZodFormField = ({
  name,
  zodFieldType,
  fieldMeta
}) => {
  const fallbackLabel = name.charAt(0).toUpperCase() + name.slice(1);
  console.log({ name, zodFieldType, fieldMeta });
  if (zodFieldType === "ZodString" && (fieldMeta == null ? void 0 : fieldMeta.secret)) {
    return /* @__PURE__ */ jsx(
      FormFieldSecret,
      {
        name,
        label: fieldMeta.label,
        helpText: fieldMeta.helpText
      }
    );
  }
  if (zodFieldType === "ZodString" || zodFieldType === "ZodNumber") {
    return /* @__PURE__ */ jsx(
      FormField,
      {
        name,
        label: (fieldMeta == null ? void 0 : fieldMeta.label) ?? fallbackLabel,
        placeholder: fieldMeta == null ? void 0 : fieldMeta.placeholder,
        helpText: fieldMeta == null ? void 0 : fieldMeta.helpText,
        type: zodFieldType === ZodNumber.name ? "number" : "text"
      }
    );
  }
  if (zodFieldType === "ZodBoolean") {
    return /* @__PURE__ */ jsx(
      Checkbox,
      {
        name,
        label: (fieldMeta == null ? void 0 : fieldMeta.label) ?? fallbackLabel,
        helpText: fieldMeta == null ? void 0 : fieldMeta.helpText
      }
    );
  }
  console.error(
    `FormFieldsFromSchema: Not implemented field type: ${zodFieldType}`
  );
  return null;
};
const ZodFormFields = ({
  name,
  zodFieldValue,
  fieldsMeta
}) => {
  const zodField = getZodField(zodFieldValue);
  const fieldType = getZodFieldTypeName(zodField);
  console.log({ name, zodFieldValue, fieldsMeta });
  if (fieldType === "ZodObject") {
    return /* @__PURE__ */ jsx(Fragment, { children: Object.entries(
      zodFieldValue.shape
    ).map(([key, value], idx) => {
      const zodField2 = getZodField(value);
      const fieldType2 = getZodFieldTypeName(zodField2);
      if (fieldType2 === "ZodObject") {
        let nestedFieldsMeta = void 0;
        if (fieldsMeta && key in fieldsMeta) {
          nestedFieldsMeta = fieldsMeta[key];
        }
        return /* @__PURE__ */ jsx(
          ZodFormFields,
          {
            name: `${name}.${key}`,
            zodFieldValue: value,
            fieldsMeta: nestedFieldsMeta
          },
          `${idx.toString()}:${key}`
        );
      } else {
        const fieldMeta = fieldsMeta == null ? void 0 : fieldsMeta[key];
        return /* @__PURE__ */ jsx(
          ZodFormField,
          {
            name: `${name}.${key}`,
            zodFieldType: fieldType2,
            fieldMeta
          },
          `${idx.toString()}:${key}`
        );
      }
    }) });
  }
  console.error(
    `FormFieldsFromSchema: Not implemented field type: ${fieldType}`
  );
  return null;
};
export {
  ConnectorForm as C,
  SmartForm as S,
  ConnectorFormType as a,
  createCommonDataSourceFieldsMeta as b,
  createCommonDataSourceSchema as c
};
//# sourceMappingURL=SmartForm-BHRjB71E.js.map
